/*
  AntiRight
  (c) 2002-2004 Jeffrey Bedard
  jefbed@e-list.net
 
  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "library.h"
#include <locale.h>

/* Set the icon and window title.  */
void
antiright_set_title(const char* name)
{
  XtVaSetValues(antiright_parent_widget, 
		XmNiconName, name, 
		XmNtitle, name, 
		NULL);
}

/* Set the icon bitmap.  */
void
antiright_set_icon(unsigned char bits[])
{
  Display *display=XtDisplay(antiright_parent_widget);
  XtVaSetValues(antiright_parent_widget, 
		XmNiconPixmap, 
		XCreateBitmapFromData(display, 
				      RootWindow(display, 
						 DefaultScreen(display)), 
				      (const char*)bits, 
				      48, 48), /* This is the only
						  size icon that will
						  be accepted!  */
		NULL);
}

void
antiright_standard_usage(char *name_string)
{
  puts( "AntiRight Desktop Environment");
  puts("Copyright 2002-2004, Jeffrey Bedard");
  puts("AntiRight is a lightweight dekstop environment.");
  puts("It is distributed under the GNU General Public License.");
  puts("There is NO WARRANTY.  Please see COPYING for details.");
  printf("Usage:  %s [OPTION]\n", name_string);
  fflush(stdout);
  puts("Command Line Options:");
  
  /* Note that some options are not included as either they do not
     work, I dont want them, or they would screw up
     operations.  */
  puts("\t[-display display]");
  puts("\t[-geometry geometry]");
  puts("\t[-bg color], [-background color]");
  puts("\t[-fg color], [-foreground color]");
  puts("\t[-iconic]");
  puts("\t[-synchronous]");
  puts("\t[-title string]");
  puts("\t[-xrm string]");
}
void
antiright_report_bugs_message()
{
  puts("Report bugs to <jefbed@e-list.net>");
}


/* Handle arguments and set up parent_widget.  The integer argc
   contains the number of arguments contained in argv.  The aray of
   character strings that is argv contains the command line arguments.
   The character string name contains the string to which the icon and
   window title will be set.  The array bits contains the icon data
   for the application icon.  */
void
antiright_initialize_application(int* argc, 
				 char** argv,
				 const char* name,
				 unsigned char bits[])
{
  /* Set up Xt.  */
  antiright_parent_widget=XtVaAppInitialize(&app_context, "AntiRight", 
					    NULL, 0, argc, argv, NULL, NULL);
  antiright_set_icon(bits);	     
  antiright_set_title(name);

  antiright_system("ACE -c &");
}

